pype32.datatypes.AlignedString

Package pype32 :: Module datatypes :: Class AlignedString |
[hide private]
[frames] | no frames]

# Class AlignedString

source code

    object --+
             |
        String --+
                 |
                AlignedString

Aligned string object.

Instance Methods | [hide private]
__init__(self, value, shouldPack=True, align=4) This object represent an aligned ASCII string. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`
Inherited from String
__len__(self) | source code
__str__(self) str(x) | source code
sizeof(self) Returns the size of the string. | source code

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, value, shouldPack=True, align=4) (Constructor) | source code
This object represent an aligned ASCII string. Parameters: `value` (str) - The string to be built. `shouldPack` (bool) - (Optional) If set to c{True}, the object will be packed. If set to `False`, the object won't be packed. `align` (int) - (Optional) The alignment to be used. The default alignment is 4. Overrides: object.__init__